@@ -13,11 +13,6 @@ describe 'heat' do
       :debug                 => 'False',
       :use_stderr            => 'True',
       :log_dir               => '/var/log/heat',
-      :rabbit_host           => '<SERVICE DEFAULT>',
-      :rabbit_port           => 5672,
-      :rabbit_userid         => '<SERVICE DEFAULT>',
-      :rabbit_password       => '<SERVICE DEFAULT>',
-      :rabbit_virtual_host   => '<SERVICE DEFAULT>',
       :database_connection   => 'mysql+pymysql://user@host/database',
       :database_idle_timeout => 3600,
       :flavor                => 'keystone',
@@ -30,25 +25,13 @@ describe 'heat' do
 
   shared_examples_for 'heat' do
 
-    context 'with rabbit_host parameter' do
+    context 'with a normal setup' do
       it_configures 'a heat base installation'
-      it_configures 'rabbit without HA support (with backward compatibility)'
+      it_configures 'configures default rabbitmq parameters'
     end
 
-    context 'with rabbit_hosts parameter' do
-      context 'with one server' do
-        before { params.merge!( :rabbit_hosts => ['127.0.0.1:5672'] ) }
-        it_configures 'a heat base installation'
-        it_configures 'rabbit without HA support (without backward compatibility)'
-      end
-
-      context 'with multiple servers' do
-        before { params.merge!(
-          :rabbit_hosts => ['rabbit1:5672', 'rabbit2:5672'],
-          :amqp_durable_queues => true) }
-        it_configures 'a heat base installation'
-        it_configures 'rabbit with HA support'
-      end
+    context 'with HA support' do
+      it_configures 'configures rabbit with HA and durable'
     end
 
     context 'with rabbit heartbeat configured' do
@@ -126,7 +109,7 @@ describe 'heat' do
     end
 
     it 'configures auth_url' do
-      is_expected.to contain_heat_config('trustee/auth_url').with_value( 'http://127.0.0.1:35357/' )
+      is_expected.to contain_heat_config('trustee/auth_url').with_value( 'http://127.0.0.1:5000/' )
     end
 
     it 'configures username' do
@@ -177,12 +160,8 @@ describe 'heat' do
 
   end
 
-  shared_examples_for 'rabbit without HA support (with backward compatibility)' do
+  shared_examples_for 'configures default rabbitmq parameters' do
     it 'configures rabbit' do
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_userid').with_value( params[:rabbit_userid] )
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_password').with_value( params[:rabbit_password] )
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_password').with_secret( true )
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value( params[:rabbit_virtual_host] )
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>')
@@ -196,82 +175,23 @@ describe 'heat' do
         :kombu_ssl_version  => '<SERVICE DEFAULT>',
       )
     end
-    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_host').with_value( params[:rabbit_host] ) }
-    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_port').with_value( params[:rabbit_port] ) }
-    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_hosts').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_heat_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_heat_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>') }
   end
 
-  shared_examples_for 'rabbit without HA support (without backward compatibility)' do
-    it 'configures rabbit' do
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_userid').with_value( params[:rabbit_userid] )
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_password').with_secret( true )
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_password').with_value( params[:rabbit_password] )
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value( params[:rabbit_virtual_host] )
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_oslo__messaging__rabbit('heat_config').with(
-        :rabbit_use_ssl     => '<SERVICE DEFAULT>',
-        :kombu_ssl_ca_certs => '<SERVICE DEFAULT>',
-        :kombu_ssl_certfile => '<SERVICE DEFAULT>',
-        :kombu_ssl_keyfile  => '<SERVICE DEFAULT>',
-        :kombu_ssl_version  => '<SERVICE DEFAULT>',
-      )
+  shared_examples_for 'configures rabbit with HA and durable' do
+    before do
+      params.merge!( :rabbit_ha_queues    => true,
+                     :amqp_durable_queues => true )
     end
-    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_hosts').with_value( params[:rabbit_hosts].join(',') ) }
-    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>') }
-  end
 
-  shared_examples_for 'rabbit with HA support' do
-    it 'configures rabbit' do
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_userid').with_value( params[:rabbit_userid] )
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_password').with_value( params[:rabbit_password] )
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_password').with_secret( true )
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value( params[:rabbit_virtual_host] )
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_oslo__messaging__rabbit('heat_config').with(
-        :rabbit_use_ssl     => '<SERVICE DEFAULT>',
-        :kombu_ssl_ca_certs => '<SERVICE DEFAULT>',
-        :kombu_ssl_certfile => '<SERVICE DEFAULT>',
-        :kombu_ssl_keyfile  => '<SERVICE DEFAULT>',
-        :kombu_ssl_version  => '<SERVICE DEFAULT>',
-      )
-    end
-    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_hosts').with_value( params[:rabbit_hosts].join(',') ) }
-    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true') }
+    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(true) }
     it { is_expected.to contain_heat_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(true) }
   end
 
-  shared_examples_for 'single rabbit_host with ha queues' do
-    let :params do
-      req_params.merge({'rabbit_ha_queues' => true})
-    end
-
-    it 'should contain rabbit_ha_queues' do
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true')
-    end
-  end
-
   shared_examples_for 'rabbit with heartbeat configured' do
     it 'configures rabbit' do
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_userid').with_value( params[:rabbit_userid] )
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_password').with_value( params[:rabbit_password] )
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_password').with_secret( true )
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value( params[:rabbit_virtual_host] )
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>')
@@ -373,12 +293,12 @@ describe 'heat' do
   shared_examples_for 'with ec2authtoken auth uri set' do
     before do
       params.merge!(
-        :keystone_ec2_uri => 'http://1.2.3.4:35357/v2.0/ec2tokens'
+        :keystone_ec2_uri => 'http://1.2.3.4:5000/v2.0/ec2tokens'
       )
     end
 
     it do
-      is_expected.to contain_heat_config('ec2authtoken/auth_uri').with_value('http://1.2.3.4:35357/v2.0/ec2tokens')
+      is_expected.to contain_heat_config('ec2authtoken/auth_uri').with_value('http://1.2.3.4:5000/v2.0/ec2tokens')
     end
   end
 
